import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:scrobbles/cubit/data_statistics_global_cubit.dart';
import 'package:scrobbles/models/statistics_global.dart';
import 'package:scrobbles/network/scrobbles.dart';
import 'package:scrobbles/ui/widgets/card_content.dart';
import 'package:scrobbles/ui/widgets/content/statistics_global.dart';
import 'package:scrobbles/ui/widgets/error.dart';

class CardStatisticsGlobal extends StatelessWidget {
  const CardStatisticsGlobal({super.key});

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<DataStatisticsGlobalCubit, DataStatisticsGlobalState>(
      builder: (BuildContext context, DataStatisticsGlobalState data) {
        final StatisticsGlobalData statistics =
            data.statisticsGlobal ?? StatisticsGlobalData.fromJson({});

        return CardContent(
          color: Theme.of(context).colorScheme.primary,
          title: 'global_statistics'.tr(),
          loader: update(),
          content: ContentStatisticsGlobal(statistics: statistics),
        );
      },
    );
  }

  Widget update() {
    const Widget loading = Text('⏳');
    const Widget done = Text('');

    late Future<StatisticsGlobalData> future = ScrobblesApi.fetchGlobalStatistics();

    return BlocBuilder<DataStatisticsGlobalCubit, DataStatisticsGlobalState>(
      builder: (BuildContext context, DataStatisticsGlobalState data) {
        return FutureBuilder<StatisticsGlobalData>(
          future: future,
          builder: (context, snapshot) {
            if (snapshot.hasError) {
              return ShowErrorWidget(message: '${snapshot.error}');
            }

            BlocProvider.of<DataStatisticsGlobalCubit>(context).update(snapshot.data);

            return !snapshot.hasData ? loading : done;
          },
        );
      },
    );
  }
}
